summaryrefslogtreecommitdiff
path: root/src/yuzu_cmd/default_ini.h
diff options
context:
space:
mode:
authorbunnei <bunneidev@gmail.com>2018-10-16 17:02:29 -0400
committerbunnei <bunneidev@gmail.com>2018-10-16 17:02:29 -0400
commitee7c2dbf5a9086a006e713fcc9eff43f18cafcc9 (patch)
tree1b6c1ee253d8111c2d74641201cec514613a3435 /src/yuzu_cmd/default_ini.h
parent91602de7f27e391c8e322a2670ef9d50a64f7517 (diff)
config: Rename use_accurate_framebuffers -> use_accurate_gpu_emulation.
- This will be used as a catch-all for slow-but-accurate GPU emulation paths.
Diffstat (limited to 'src/yuzu_cmd/default_ini.h')
-rw-r--r--src/yuzu_cmd/default_ini.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/yuzu_cmd/default_ini.h b/src/yuzu_cmd/default_ini.h
index 762396e3b..a97b75f7b 100644
--- a/src/yuzu_cmd/default_ini.h
+++ b/src/yuzu_cmd/default_ini.h
@@ -110,9 +110,9 @@ use_frame_limit =
# 1 - 9999: Speed limit as a percentage of target game speed. 100 (default)
frame_limit =
# Whether to use accurate framebuffers
# 0 (default): Off (fast), 1 : On (slow)
-use_accurate_framebuffers =
+use_accurate_gpu_emulation =
# The clear color for the renderer. What shows up on the sides of the bottom screen.
# Must be in range of 0.0-1.0. Defaults to 1.0 for all.
@@ -110,9 +110,9 @@ use_frame_limit =
# 1 - 9999: Speed limit as a percentage of target game speed. 100 (default)
frame_limit =
-# Whether to use accurate framebuffers
+# Whether to use accurate GPU emulation
# 0 (default): Off (fast), 1 : On (slow)